/****************************************************************************
** Meta object code from reading C++ file 'actioncollectionview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kross-5.39.0/src/ui/actioncollectionview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'actioncollectionview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kross__ActionCollectionView_t {
    QByteArrayData data[14];
    char stringdata0[176];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kross__ActionCollectionView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kross__ActionCollectionView_t qt_meta_stringdata_Kross__ActionCollectionView = {
    {
QT_MOC_LITERAL(0, 0, 27), // "Kross::ActionCollectionView"
QT_MOC_LITERAL(1, 28, 14), // "enabledChanged"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 10), // "actionname"
QT_MOC_LITERAL(4, 55, 7), // "slotRun"
QT_MOC_LITERAL(5, 63, 8), // "slotStop"
QT_MOC_LITERAL(6, 72, 8), // "slotEdit"
QT_MOC_LITERAL(7, 81, 7), // "slotAdd"
QT_MOC_LITERAL(8, 89, 10), // "slotRemove"
QT_MOC_LITERAL(9, 100, 15), // "slotDataChanged"
QT_MOC_LITERAL(10, 116, 7), // "topLeft"
QT_MOC_LITERAL(11, 124, 11), // "bottomRight"
QT_MOC_LITERAL(12, 136, 18), // "slotEnabledChanged"
QT_MOC_LITERAL(13, 155, 20) // "slotSelectionChanged"

    },
    "Kross::ActionCollectionView\0enabledChanged\0"
    "\0actionname\0slotRun\0slotStop\0slotEdit\0"
    "slotAdd\0slotRemove\0slotDataChanged\0"
    "topLeft\0bottomRight\0slotEnabledChanged\0"
    "slotSelectionChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kross__ActionCollectionView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   62,    2, 0x0a /* Public */,
       5,    0,   63,    2, 0x0a /* Public */,
       6,    0,   64,    2, 0x0a /* Public */,
       7,    0,   65,    2, 0x0a /* Public */,
       8,    0,   66,    2, 0x0a /* Public */,
       9,    2,   67,    2, 0x09 /* Protected */,
      12,    1,   72,    2, 0x09 /* Protected */,
      13,    0,   75,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::QModelIndex,   10,   11,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,

       0        // eod
};

void Kross::ActionCollectionView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ActionCollectionView *_t = static_cast<ActionCollectionView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->enabledChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->slotRun(); break;
        case 2: _t->slotStop(); break;
        case 3: _t->slotEdit(); break;
        case 4: _t->slotAdd(); break;
        case 5: _t->slotRemove(); break;
        case 6: _t->slotDataChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 7: _t->slotEnabledChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->slotSelectionChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ActionCollectionView::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ActionCollectionView::enabledChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject Kross::ActionCollectionView::staticMetaObject = {
    { &QTreeView::staticMetaObject, qt_meta_stringdata_Kross__ActionCollectionView.data,
      qt_meta_data_Kross__ActionCollectionView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kross::ActionCollectionView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kross::ActionCollectionView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kross__ActionCollectionView.stringdata0))
        return static_cast<void*>(this);
    return QTreeView::qt_metacast(_clname);
}

int Kross::ActionCollectionView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Kross::ActionCollectionView::enabledChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
