/****************************************************************************
** Meta object code from reading C++ file 'actioncollectionmodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kross-5.39.0/src/ui/actioncollectionmodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'actioncollectionmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kross__ActionCollectionModel_t {
    QByteArrayData data[16];
    char stringdata0[277];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kross__ActionCollectionModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kross__ActionCollectionModel_t qt_meta_stringdata_Kross__ActionCollectionModel = {
    {
QT_MOC_LITERAL(0, 0, 28), // "Kross::ActionCollectionModel"
QT_MOC_LITERAL(1, 29, 11), // "slotUpdated"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 15), // "slotDataChanged"
QT_MOC_LITERAL(4, 58, 17), // "ActionCollection*"
QT_MOC_LITERAL(5, 76, 7), // "Action*"
QT_MOC_LITERAL(6, 84, 26), // "slotCollectionToBeInserted"
QT_MOC_LITERAL(7, 111, 5), // "child"
QT_MOC_LITERAL(8, 117, 6), // "parent"
QT_MOC_LITERAL(9, 124, 22), // "slotCollectionInserted"
QT_MOC_LITERAL(10, 147, 25), // "slotCollectionToBeRemoved"
QT_MOC_LITERAL(11, 173, 21), // "slotCollectionRemoved"
QT_MOC_LITERAL(12, 195, 22), // "slotActionToBeInserted"
QT_MOC_LITERAL(13, 218, 18), // "slotActionInserted"
QT_MOC_LITERAL(14, 237, 21), // "slotActionToBeRemoved"
QT_MOC_LITERAL(15, 259, 17) // "slotActionRemoved"

    },
    "Kross::ActionCollectionModel\0slotUpdated\0"
    "\0slotDataChanged\0ActionCollection*\0"
    "Action*\0slotCollectionToBeInserted\0"
    "child\0parent\0slotCollectionInserted\0"
    "slotCollectionToBeRemoved\0"
    "slotCollectionRemoved\0slotActionToBeInserted\0"
    "slotActionInserted\0slotActionToBeRemoved\0"
    "slotActionRemoved"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kross__ActionCollectionModel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x08 /* Private */,
       3,    1,   70,    2, 0x08 /* Private */,
       3,    1,   73,    2, 0x08 /* Private */,
       6,    2,   76,    2, 0x08 /* Private */,
       9,    2,   81,    2, 0x08 /* Private */,
      10,    2,   86,    2, 0x08 /* Private */,
      11,    2,   91,    2, 0x08 /* Private */,
      12,    2,   96,    2, 0x08 /* Private */,
      13,    2,  101,    2, 0x08 /* Private */,
      14,    2,  106,    2, 0x08 /* Private */,
      15,    2,  111,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 4,    7,    8,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 4,    7,    8,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 4,    7,    8,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 4,    7,    8,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 4,    7,    8,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 4,    7,    8,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 4,    7,    8,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 4,    7,    8,

       0        // eod
};

void Kross::ActionCollectionModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ActionCollectionModel *_t = static_cast<ActionCollectionModel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotUpdated(); break;
        case 1: _t->slotDataChanged((*reinterpret_cast< ActionCollection*(*)>(_a[1]))); break;
        case 2: _t->slotDataChanged((*reinterpret_cast< Action*(*)>(_a[1]))); break;
        case 3: _t->slotCollectionToBeInserted((*reinterpret_cast< ActionCollection*(*)>(_a[1])),(*reinterpret_cast< ActionCollection*(*)>(_a[2]))); break;
        case 4: _t->slotCollectionInserted((*reinterpret_cast< ActionCollection*(*)>(_a[1])),(*reinterpret_cast< ActionCollection*(*)>(_a[2]))); break;
        case 5: _t->slotCollectionToBeRemoved((*reinterpret_cast< ActionCollection*(*)>(_a[1])),(*reinterpret_cast< ActionCollection*(*)>(_a[2]))); break;
        case 6: _t->slotCollectionRemoved((*reinterpret_cast< ActionCollection*(*)>(_a[1])),(*reinterpret_cast< ActionCollection*(*)>(_a[2]))); break;
        case 7: _t->slotActionToBeInserted((*reinterpret_cast< Action*(*)>(_a[1])),(*reinterpret_cast< ActionCollection*(*)>(_a[2]))); break;
        case 8: _t->slotActionInserted((*reinterpret_cast< Action*(*)>(_a[1])),(*reinterpret_cast< ActionCollection*(*)>(_a[2]))); break;
        case 9: _t->slotActionToBeRemoved((*reinterpret_cast< Action*(*)>(_a[1])),(*reinterpret_cast< ActionCollection*(*)>(_a[2]))); break;
        case 10: _t->slotActionRemoved((*reinterpret_cast< Action*(*)>(_a[1])),(*reinterpret_cast< ActionCollection*(*)>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject Kross::ActionCollectionModel::staticMetaObject = {
    { &QAbstractItemModel::staticMetaObject, qt_meta_stringdata_Kross__ActionCollectionModel.data,
      qt_meta_data_Kross__ActionCollectionModel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kross::ActionCollectionModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kross::ActionCollectionModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kross__ActionCollectionModel.stringdata0))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int Kross::ActionCollectionModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
