/****************************************************************************
** Meta object code from reading C++ file 'script.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kross-5.39.0/src/core/script.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'script.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kross__Script_t {
    QByteArrayData data[13];
    char stringdata0[114];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kross__Script_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kross__Script_t qt_meta_stringdata_Kross__Script = {
    {
QT_MOC_LITERAL(0, 0, 13), // "Kross::Script"
QT_MOC_LITERAL(1, 14, 11), // "interpreter"
QT_MOC_LITERAL(2, 26, 12), // "Interpreter*"
QT_MOC_LITERAL(3, 39, 0), // ""
QT_MOC_LITERAL(4, 40, 6), // "action"
QT_MOC_LITERAL(5, 47, 7), // "Action*"
QT_MOC_LITERAL(6, 55, 7), // "execute"
QT_MOC_LITERAL(7, 63, 13), // "functionNames"
QT_MOC_LITERAL(8, 77, 12), // "callFunction"
QT_MOC_LITERAL(9, 90, 4), // "name"
QT_MOC_LITERAL(10, 95, 4), // "args"
QT_MOC_LITERAL(11, 100, 8), // "evaluate"
QT_MOC_LITERAL(12, 109, 4) // "code"

    },
    "Kross::Script\0interpreter\0Interpreter*\0"
    "\0action\0Action*\0execute\0functionNames\0"
    "callFunction\0name\0args\0evaluate\0code"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kross__Script[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   49,    3, 0x0a /* Public */,
       4,    0,   50,    3, 0x0a /* Public */,
       6,    0,   51,    3, 0x0a /* Public */,
       7,    0,   52,    3, 0x0a /* Public */,
       8,    2,   53,    3, 0x0a /* Public */,
       8,    1,   58,    3, 0x2a /* Public | MethodCloned */,
      11,    1,   61,    3, 0x0a /* Public */,

 // slots: parameters
    0x80000000 | 2,
    0x80000000 | 5,
    QMetaType::Void,
    QMetaType::QStringList,
    QMetaType::QVariant, QMetaType::QString, QMetaType::QVariantList,    9,   10,
    QMetaType::QVariant, QMetaType::QString,    9,
    QMetaType::QVariant, QMetaType::QByteArray,   12,

       0        // eod
};

void Kross::Script::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Script *_t = static_cast<Script *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { Interpreter* _r = _t->interpreter();
            if (_a[0]) *reinterpret_cast< Interpreter**>(_a[0]) = std::move(_r); }  break;
        case 1: { Action* _r = _t->action();
            if (_a[0]) *reinterpret_cast< Action**>(_a[0]) = std::move(_r); }  break;
        case 2: _t->execute(); break;
        case 3: { QStringList _r = _t->functionNames();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 4: { QVariant _r = _t->callFunction((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantList(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QVariant*>(_a[0]) = std::move(_r); }  break;
        case 5: { QVariant _r = _t->callFunction((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariant*>(_a[0]) = std::move(_r); }  break;
        case 6: { QVariant _r = _t->evaluate((*reinterpret_cast< const QByteArray(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariant*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject Kross::Script::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Kross__Script.data,
      qt_meta_data_Kross__Script,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kross::Script::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kross::Script::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kross__Script.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ErrorInterface"))
        return static_cast< ErrorInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int Kross::Script::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
