/****************************************************************************
** Meta object code from reading C++ file 'form.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kross-5.39.0/src/modules/form.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'form.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kross__FormListView_t {
    QByteArrayData data[11];
    char stringdata0[82];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kross__FormListView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kross__FormListView_t qt_meta_stringdata_Kross__FormListView = {
    {
QT_MOC_LITERAL(0, 0, 19), // "Kross::FormListView"
QT_MOC_LITERAL(1, 20, 5), // "clear"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 6), // "remove"
QT_MOC_LITERAL(4, 34, 5), // "index"
QT_MOC_LITERAL(5, 40, 7), // "addItem"
QT_MOC_LITERAL(6, 48, 4), // "text"
QT_MOC_LITERAL(7, 53, 5), // "count"
QT_MOC_LITERAL(8, 59, 7), // "current"
QT_MOC_LITERAL(9, 67, 10), // "setCurrent"
QT_MOC_LITERAL(10, 78, 3) // "row"

    },
    "Kross::FormListView\0clear\0\0remove\0"
    "index\0addItem\0text\0count\0current\0"
    "setCurrent\0row"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kross__FormListView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x0a /* Public */,
       3,    1,   50,    2, 0x0a /* Public */,
       5,    1,   53,    2, 0x0a /* Public */,
       7,    0,   56,    2, 0x0a /* Public */,
       8,    0,   57,    2, 0x0a /* Public */,
       9,    1,   58,    2, 0x0a /* Public */,
       6,    1,   61,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Int,
    QMetaType::Int,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::QString, QMetaType::Int,   10,

       0        // eod
};

void Kross::FormListView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FormListView *_t = static_cast<FormListView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->clear(); break;
        case 1: _t->remove((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->addItem((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: { int _r = _t->count();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 4: { int _r = _t->current();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->setCurrent((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: { QString _r = _t->text((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject Kross::FormListView::staticMetaObject = {
    { &QListWidget::staticMetaObject, qt_meta_stringdata_Kross__FormListView.data,
      qt_meta_data_Kross__FormListView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kross::FormListView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kross::FormListView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kross__FormListView.stringdata0))
        return static_cast<void*>(this);
    return QListWidget::qt_metacast(_clname);
}

int Kross::FormListView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QListWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
struct qt_meta_stringdata_Kross__FormFileWidget_t {
    QByteArrayData data[21];
    char stringdata0[240];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kross__FormFileWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kross__FormFileWidget_t qt_meta_stringdata_Kross__FormFileWidget = {
    {
QT_MOC_LITERAL(0, 0, 21), // "Kross::FormFileWidget"
QT_MOC_LITERAL(1, 22, 12), // "fileSelected"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 4), // "file"
QT_MOC_LITERAL(4, 41, 15), // "fileHighlighted"
QT_MOC_LITERAL(5, 57, 16), // "selectionChanged"
QT_MOC_LITERAL(6, 74, 13), // "filterChanged"
QT_MOC_LITERAL(7, 88, 6), // "filter"
QT_MOC_LITERAL(8, 95, 7), // "setMode"
QT_MOC_LITERAL(9, 103, 4), // "mode"
QT_MOC_LITERAL(10, 108, 13), // "currentFilter"
QT_MOC_LITERAL(11, 122, 9), // "setFilter"
QT_MOC_LITERAL(12, 132, 17), // "currentMimeFilter"
QT_MOC_LITERAL(13, 150, 13), // "setMimeFilter"
QT_MOC_LITERAL(14, 164, 12), // "selectedFile"
QT_MOC_LITERAL(15, 177, 16), // "slotFileSelected"
QT_MOC_LITERAL(16, 194, 19), // "slotFileHighlighted"
QT_MOC_LITERAL(17, 214, 4), // "Mode"
QT_MOC_LITERAL(18, 219, 5), // "Other"
QT_MOC_LITERAL(19, 225, 7), // "Opening"
QT_MOC_LITERAL(20, 233, 6) // "Saving"

    },
    "Kross::FormFileWidget\0fileSelected\0\0"
    "file\0fileHighlighted\0selectionChanged\0"
    "filterChanged\0filter\0setMode\0mode\0"
    "currentFilter\0setFilter\0currentMimeFilter\0"
    "setMimeFilter\0selectedFile\0slotFileSelected\0"
    "slotFileHighlighted\0Mode\0Other\0Opening\0"
    "Saving"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kross__FormFileWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       1,  102, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x06 /* Public */,
       4,    1,   77,    2, 0x06 /* Public */,
       5,    0,   80,    2, 0x06 /* Public */,
       6,    1,   81,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    1,   84,    2, 0x0a /* Public */,
      10,    0,   87,    2, 0x0a /* Public */,
      11,    1,   88,    2, 0x0a /* Public */,
      12,    0,   91,    2, 0x0a /* Public */,
      13,    1,   92,    2, 0x0a /* Public */,
      14,    0,   95,    2, 0x0a /* Public */,
      15,    1,   96,    2, 0x08 /* Private */,
      16,    1,   99,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    7,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::QString,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::QString,
    QMetaType::Void, QMetaType::QStringList,    7,
    QMetaType::QString,
    QMetaType::Void, QMetaType::QUrl,    2,
    QMetaType::Void, QMetaType::QUrl,    2,

 // enums: name, flags, count, data
      17, 0x0,    3,  106,

 // enum data: key, value
      18, uint(Kross::FormFileWidget::Other),
      19, uint(Kross::FormFileWidget::Opening),
      20, uint(Kross::FormFileWidget::Saving),

       0        // eod
};

void Kross::FormFileWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FormFileWidget *_t = static_cast<FormFileWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->fileSelected((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->fileHighlighted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->selectionChanged(); break;
        case 3: _t->filterChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->setMode((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: { QString _r = _t->currentFilter();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->setFilter((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: { QString _r = _t->currentMimeFilter();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->setMimeFilter((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 9: { QString _r = _t->selectedFile();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->slotFileSelected((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 11: _t->slotFileHighlighted((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (FormFileWidget::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&FormFileWidget::fileSelected)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (FormFileWidget::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&FormFileWidget::fileHighlighted)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (FormFileWidget::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&FormFileWidget::selectionChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (FormFileWidget::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&FormFileWidget::filterChanged)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject Kross::FormFileWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Kross__FormFileWidget.data,
      qt_meta_data_Kross__FormFileWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kross::FormFileWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kross::FormFileWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kross__FormFileWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Kross::FormFileWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Kross::FormFileWidget::fileSelected(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Kross::FormFileWidget::fileHighlighted(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Kross::FormFileWidget::selectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Kross::FormFileWidget::filterChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
struct qt_meta_stringdata_Kross__FormProgressDialog_t {
    QByteArrayData data[14];
    char stringdata0[126];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kross__FormProgressDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kross__FormProgressDialog_t qt_meta_stringdata_Kross__FormProgressDialog = {
    {
QT_MOC_LITERAL(0, 0, 25), // "Kross::FormProgressDialog"
QT_MOC_LITERAL(1, 26, 8), // "canceled"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 8), // "setValue"
QT_MOC_LITERAL(4, 45, 8), // "progress"
QT_MOC_LITERAL(5, 54, 8), // "setRange"
QT_MOC_LITERAL(6, 63, 7), // "minimum"
QT_MOC_LITERAL(7, 71, 7), // "maximum"
QT_MOC_LITERAL(8, 79, 7), // "setText"
QT_MOC_LITERAL(9, 87, 4), // "text"
QT_MOC_LITERAL(10, 92, 7), // "addText"
QT_MOC_LITERAL(11, 100, 4), // "exec"
QT_MOC_LITERAL(12, 105, 9), // "exec_loop"
QT_MOC_LITERAL(13, 115, 10) // "isCanceled"

    },
    "Kross::FormProgressDialog\0canceled\0\0"
    "setValue\0progress\0setRange\0minimum\0"
    "maximum\0setText\0text\0addText\0exec\0"
    "exec_loop\0isCanceled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kross__FormProgressDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   54,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   55,    2, 0x0a /* Public */,
       5,    2,   58,    2, 0x0a /* Public */,
       8,    1,   63,    2, 0x0a /* Public */,
      10,    1,   66,    2, 0x0a /* Public */,
      11,    0,   69,    2, 0x0a /* Public */,
      12,    0,   70,    2, 0x0a /* Public */,
      13,    0,   71,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    6,    7,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Int,
    QMetaType::Int,
    QMetaType::Bool,

       0        // eod
};

void Kross::FormProgressDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FormProgressDialog *_t = static_cast<FormProgressDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->canceled(); break;
        case 1: _t->setValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->setRange((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->setText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->addText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: { int _r = _t->exec();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 6: { int _r = _t->exec_loop();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->isCanceled();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (FormProgressDialog::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&FormProgressDialog::canceled)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject Kross::FormProgressDialog::staticMetaObject = {
    { &KPageDialog::staticMetaObject, qt_meta_stringdata_Kross__FormProgressDialog.data,
      qt_meta_data_Kross__FormProgressDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kross::FormProgressDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kross::FormProgressDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kross__FormProgressDialog.stringdata0))
        return static_cast<void*>(this);
    return KPageDialog::qt_metacast(_clname);
}

int Kross::FormProgressDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPageDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Kross::FormProgressDialog::canceled()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_Kross__FormDialog_t {
    QByteArrayData data[25];
    char stringdata0[260];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kross__FormDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kross__FormDialog_t qt_meta_stringdata_Kross__FormDialog = {
    {
QT_MOC_LITERAL(0, 0, 17), // "Kross::FormDialog"
QT_MOC_LITERAL(1, 18, 10), // "setButtons"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 7), // "buttons"
QT_MOC_LITERAL(4, 38, 13), // "setButtonText"
QT_MOC_LITERAL(5, 52, 6), // "button"
QT_MOC_LITERAL(6, 59, 4), // "text"
QT_MOC_LITERAL(7, 64, 11), // "setFaceType"
QT_MOC_LITERAL(8, 76, 8), // "facetype"
QT_MOC_LITERAL(9, 85, 11), // "currentPage"
QT_MOC_LITERAL(10, 97, 14), // "setCurrentPage"
QT_MOC_LITERAL(11, 112, 4), // "name"
QT_MOC_LITERAL(12, 117, 4), // "page"
QT_MOC_LITERAL(13, 122, 8), // "QWidget*"
QT_MOC_LITERAL(14, 131, 7), // "addPage"
QT_MOC_LITERAL(15, 139, 6), // "header"
QT_MOC_LITERAL(16, 146, 8), // "iconname"
QT_MOC_LITERAL(17, 155, 4), // "exec"
QT_MOC_LITERAL(18, 160, 9), // "exec_loop"
QT_MOC_LITERAL(19, 170, 6), // "result"
QT_MOC_LITERAL(20, 177, 17), // "slotButtonClicked"
QT_MOC_LITERAL(21, 195, 16), // "QAbstractButton*"
QT_MOC_LITERAL(22, 212, 22), // "slotCurrentPageChanged"
QT_MOC_LITERAL(23, 235, 16), // "KPageWidgetItem*"
QT_MOC_LITERAL(24, 252, 7) // "current"

    },
    "Kross::FormDialog\0setButtons\0\0buttons\0"
    "setButtonText\0button\0text\0setFaceType\0"
    "facetype\0currentPage\0setCurrentPage\0"
    "name\0page\0QWidget*\0addPage\0header\0"
    "iconname\0exec\0exec_loop\0result\0"
    "slotButtonClicked\0QAbstractButton*\0"
    "slotCurrentPageChanged\0KPageWidgetItem*\0"
    "current"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kross__FormDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   84,    2, 0x0a /* Public */,
       4,    2,   87,    2, 0x0a /* Public */,
       7,    1,   92,    2, 0x0a /* Public */,
       9,    0,   95,    2, 0x0a /* Public */,
      10,    1,   96,    2, 0x0a /* Public */,
      12,    1,   99,    2, 0x0a /* Public */,
      14,    3,  102,    2, 0x0a /* Public */,
      14,    2,  109,    2, 0x2a /* Public | MethodCloned */,
      14,    1,  114,    2, 0x2a /* Public | MethodCloned */,
      17,    0,  117,    2, 0x0a /* Public */,
      18,    0,  118,    2, 0x0a /* Public */,
      19,    0,  119,    2, 0x0a /* Public */,
      20,    1,  120,    2, 0x08 /* Private */,
      22,    1,  123,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Bool, QMetaType::QString,    3,
    QMetaType::Bool, QMetaType::QString, QMetaType::QString,    5,    6,
    QMetaType::Bool, QMetaType::QString,    8,
    QMetaType::QString,
    QMetaType::Bool, QMetaType::QString,   11,
    0x80000000 | 13, QMetaType::QString,   11,
    0x80000000 | 13, QMetaType::QString, QMetaType::QString, QMetaType::QString,   11,   15,   16,
    0x80000000 | 13, QMetaType::QString, QMetaType::QString,   11,   15,
    0x80000000 | 13, QMetaType::QString,   11,
    QMetaType::Int,
    QMetaType::Int,
    QMetaType::QString,
    QMetaType::Void, 0x80000000 | 21,    5,
    QMetaType::Void, 0x80000000 | 23,   24,

       0        // eod
};

void Kross::FormDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FormDialog *_t = static_cast<FormDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { bool _r = _t->setButtons((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->setButtonText((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->setFaceType((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->currentPage();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->setCurrentPage((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { QWidget* _r = _t->page((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 6: { QWidget* _r = _t->addPage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 7: { QWidget* _r = _t->addPage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 8: { QWidget* _r = _t->addPage((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 9: { int _r = _t->exec();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 10: { int _r = _t->exec_loop();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->result();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->slotButtonClicked((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
        case 13: _t->slotCurrentPageChanged((*reinterpret_cast< KPageWidgetItem*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPageWidgetItem* >(); break;
            }
            break;
        }
    }
}

const QMetaObject Kross::FormDialog::staticMetaObject = {
    { &KPageDialog::staticMetaObject, qt_meta_stringdata_Kross__FormDialog.data,
      qt_meta_data_Kross__FormDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kross::FormDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kross::FormDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kross__FormDialog.stringdata0))
        return static_cast<void*>(this);
    return KPageDialog::qt_metacast(_clname);
}

int Kross::FormDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPageDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}
struct qt_meta_stringdata_Kross__FormAssistant_t {
    QByteArrayData data[39];
    char stringdata0[390];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kross__FormAssistant_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kross__FormAssistant_t qt_meta_stringdata_Kross__FormAssistant = {
    {
QT_MOC_LITERAL(0, 0, 20), // "Kross::FormAssistant"
QT_MOC_LITERAL(1, 21, 11), // "nextClicked"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 11), // "backClicked"
QT_MOC_LITERAL(4, 46, 14), // "showHelpButton"
QT_MOC_LITERAL(5, 61, 11), // "currentPage"
QT_MOC_LITERAL(6, 73, 14), // "setCurrentPage"
QT_MOC_LITERAL(7, 88, 4), // "name"
QT_MOC_LITERAL(8, 93, 4), // "page"
QT_MOC_LITERAL(9, 98, 8), // "QWidget*"
QT_MOC_LITERAL(10, 107, 7), // "addPage"
QT_MOC_LITERAL(11, 115, 6), // "header"
QT_MOC_LITERAL(12, 122, 8), // "iconname"
QT_MOC_LITERAL(13, 131, 13), // "isAppropriate"
QT_MOC_LITERAL(14, 145, 14), // "setAppropriate"
QT_MOC_LITERAL(15, 160, 11), // "appropriate"
QT_MOC_LITERAL(16, 172, 7), // "isValid"
QT_MOC_LITERAL(17, 180, 8), // "setValid"
QT_MOC_LITERAL(18, 189, 6), // "enable"
QT_MOC_LITERAL(19, 196, 4), // "exec"
QT_MOC_LITERAL(20, 201, 9), // "exec_loop"
QT_MOC_LITERAL(21, 211, 6), // "result"
QT_MOC_LITERAL(22, 218, 4), // "back"
QT_MOC_LITERAL(23, 223, 4), // "next"
QT_MOC_LITERAL(24, 228, 17), // "slotButtonClicked"
QT_MOC_LITERAL(25, 246, 16), // "QAbstractButton*"
QT_MOC_LITERAL(26, 263, 6), // "button"
QT_MOC_LITERAL(27, 270, 22), // "slotCurrentPageChanged"
QT_MOC_LITERAL(28, 293, 16), // "KPageWidgetItem*"
QT_MOC_LITERAL(29, 310, 7), // "current"
QT_MOC_LITERAL(30, 318, 19), // "AssistantButtonCode"
QT_MOC_LITERAL(31, 338, 4), // "None"
QT_MOC_LITERAL(32, 343, 4), // "Help"
QT_MOC_LITERAL(33, 348, 7), // "Default"
QT_MOC_LITERAL(34, 356, 6), // "Cancel"
QT_MOC_LITERAL(35, 363, 6), // "Finish"
QT_MOC_LITERAL(36, 370, 4), // "Next"
QT_MOC_LITERAL(37, 375, 4), // "Back"
QT_MOC_LITERAL(38, 380, 9) // "NoDefault"

    },
    "Kross::FormAssistant\0nextClicked\0\0"
    "backClicked\0showHelpButton\0currentPage\0"
    "setCurrentPage\0name\0page\0QWidget*\0"
    "addPage\0header\0iconname\0isAppropriate\0"
    "setAppropriate\0appropriate\0isValid\0"
    "setValid\0enable\0exec\0exec_loop\0result\0"
    "back\0next\0slotButtonClicked\0"
    "QAbstractButton*\0button\0slotCurrentPageChanged\0"
    "KPageWidgetItem*\0current\0AssistantButtonCode\0"
    "None\0Help\0Default\0Cancel\0Finish\0Next\0"
    "Back\0NoDefault"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kross__FormAssistant[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      20,   14, // methods
       0,    0, // properties
       1,  168, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  114,    2, 0x06 /* Public */,
       3,    0,  115,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,  116,    2, 0x0a /* Public */,
       5,    0,  119,    2, 0x0a /* Public */,
       6,    1,  120,    2, 0x0a /* Public */,
       8,    1,  123,    2, 0x0a /* Public */,
      10,    3,  126,    2, 0x0a /* Public */,
      10,    2,  133,    2, 0x2a /* Public | MethodCloned */,
      10,    1,  138,    2, 0x2a /* Public | MethodCloned */,
      13,    1,  141,    2, 0x0a /* Public */,
      14,    2,  144,    2, 0x0a /* Public */,
      16,    1,  149,    2, 0x0a /* Public */,
      17,    2,  152,    2, 0x0a /* Public */,
      19,    0,  157,    2, 0x0a /* Public */,
      20,    0,  158,    2, 0x0a /* Public */,
      21,    0,  159,    2, 0x0a /* Public */,
      22,    0,  160,    2, 0x0a /* Public */,
      23,    0,  161,    2, 0x0a /* Public */,
      24,    1,  162,    2, 0x08 /* Private */,
      27,    1,  165,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::QString,
    QMetaType::Bool, QMetaType::QString,    7,
    0x80000000 | 9, QMetaType::QString,    7,
    0x80000000 | 9, QMetaType::QString, QMetaType::QString, QMetaType::QString,    7,   11,   12,
    0x80000000 | 9, QMetaType::QString, QMetaType::QString,    7,   11,
    0x80000000 | 9, QMetaType::QString,    7,
    QMetaType::Bool, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,    7,   15,
    QMetaType::Bool, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,    7,   18,
    QMetaType::Int,
    QMetaType::Int,
    QMetaType::QString,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 25,   26,
    QMetaType::Void, 0x80000000 | 28,   29,

 // enums: name, flags, count, data
      30, 0x0,    8,  172,

 // enum data: key, value
      31, uint(Kross::FormAssistant::None),
      32, uint(Kross::FormAssistant::Help),
      33, uint(Kross::FormAssistant::Default),
      34, uint(Kross::FormAssistant::Cancel),
      35, uint(Kross::FormAssistant::Finish),
      36, uint(Kross::FormAssistant::Next),
      37, uint(Kross::FormAssistant::Back),
      38, uint(Kross::FormAssistant::NoDefault),

       0        // eod
};

void Kross::FormAssistant::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FormAssistant *_t = static_cast<FormAssistant *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->nextClicked(); break;
        case 1: _t->backClicked(); break;
        case 2: _t->showHelpButton((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: { QString _r = _t->currentPage();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->setCurrentPage((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { QWidget* _r = _t->page((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 6: { QWidget* _r = _t->addPage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 7: { QWidget* _r = _t->addPage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 8: { QWidget* _r = _t->addPage((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->isAppropriate((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setAppropriate((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 11: { bool _r = _t->isValid((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->setValid((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 13: { int _r = _t->exec();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 14: { int _r = _t->exec_loop();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 15: { QString _r = _t->result();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->back(); break;
        case 17: _t->next(); break;
        case 18: _t->slotButtonClicked((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
        case 19: _t->slotCurrentPageChanged((*reinterpret_cast< KPageWidgetItem*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPageWidgetItem* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (FormAssistant::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&FormAssistant::nextClicked)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (FormAssistant::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&FormAssistant::backClicked)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject Kross::FormAssistant::staticMetaObject = {
    { &KAssistantDialog::staticMetaObject, qt_meta_stringdata_Kross__FormAssistant.data,
      qt_meta_data_Kross__FormAssistant,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kross::FormAssistant::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kross::FormAssistant::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kross__FormAssistant.stringdata0))
        return static_cast<void*>(this);
    return KAssistantDialog::qt_metacast(_clname);
}

int Kross::FormAssistant::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KAssistantDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void Kross::FormAssistant::nextClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Kross::FormAssistant::backClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
struct qt_meta_stringdata_Kross__FormModule_t {
    QByteArrayData data[34];
    char stringdata0[378];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kross__FormModule_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kross__FormModule_t qt_meta_stringdata_Kross__FormModule = {
    {
QT_MOC_LITERAL(0, 0, 17), // "Kross::FormModule"
QT_MOC_LITERAL(1, 18, 17), // "activeModalWidget"
QT_MOC_LITERAL(2, 36, 8), // "QWidget*"
QT_MOC_LITERAL(3, 45, 0), // ""
QT_MOC_LITERAL(4, 46, 12), // "activeWindow"
QT_MOC_LITERAL(5, 59, 2), // "tr"
QT_MOC_LITERAL(6, 62, 3), // "str"
QT_MOC_LITERAL(7, 66, 7), // "comment"
QT_MOC_LITERAL(8, 74, 14), // "showMessageBox"
QT_MOC_LITERAL(9, 89, 10), // "dialogtype"
QT_MOC_LITERAL(10, 100, 7), // "caption"
QT_MOC_LITERAL(11, 108, 7), // "message"
QT_MOC_LITERAL(12, 116, 7), // "details"
QT_MOC_LITERAL(13, 124, 18), // "showProgressDialog"
QT_MOC_LITERAL(14, 143, 9), // "labelText"
QT_MOC_LITERAL(15, 153, 12), // "createDialog"
QT_MOC_LITERAL(16, 166, 15), // "createAssistant"
QT_MOC_LITERAL(17, 182, 12), // "createLayout"
QT_MOC_LITERAL(18, 195, 6), // "parent"
QT_MOC_LITERAL(19, 202, 6), // "layout"
QT_MOC_LITERAL(20, 209, 12), // "createWidget"
QT_MOC_LITERAL(21, 222, 9), // "className"
QT_MOC_LITERAL(22, 232, 4), // "name"
QT_MOC_LITERAL(23, 237, 18), // "createWidgetFromUI"
QT_MOC_LITERAL(24, 256, 3), // "xml"
QT_MOC_LITERAL(25, 260, 22), // "createWidgetFromUIFile"
QT_MOC_LITERAL(26, 283, 8), // "filename"
QT_MOC_LITERAL(27, 292, 16), // "createFileWidget"
QT_MOC_LITERAL(28, 309, 18), // "startDirOrVariable"
QT_MOC_LITERAL(29, 328, 14), // "createListView"
QT_MOC_LITERAL(30, 343, 8), // "loadPart"
QT_MOC_LITERAL(31, 352, 3), // "url"
QT_MOC_LITERAL(32, 356, 12), // "createAction"
QT_MOC_LITERAL(33, 369, 8) // "QAction*"

    },
    "Kross::FormModule\0activeModalWidget\0"
    "QWidget*\0\0activeWindow\0tr\0str\0comment\0"
    "showMessageBox\0dialogtype\0caption\0"
    "message\0details\0showProgressDialog\0"
    "labelText\0createDialog\0createAssistant\0"
    "createLayout\0parent\0layout\0createWidget\0"
    "className\0name\0createWidgetFromUI\0xml\0"
    "createWidgetFromUIFile\0filename\0"
    "createFileWidget\0startDirOrVariable\0"
    "createListView\0loadPart\0url\0createAction\0"
    "QAction*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kross__FormModule[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  119,    3, 0x0a /* Public */,
       4,    0,  120,    3, 0x0a /* Public */,
       5,    1,  121,    3, 0x0a /* Public */,
       5,    2,  124,    3, 0x0a /* Public */,
       8,    4,  129,    3, 0x0a /* Public */,
       8,    3,  138,    3, 0x2a /* Public | MethodCloned */,
      13,    2,  145,    3, 0x0a /* Public */,
      15,    1,  150,    3, 0x0a /* Public */,
      16,    1,  153,    3, 0x0a /* Public */,
      17,    2,  156,    3, 0x0a /* Public */,
      20,    1,  161,    3, 0x0a /* Public */,
      20,    3,  164,    3, 0x0a /* Public */,
      20,    2,  171,    3, 0x2a /* Public | MethodCloned */,
      23,    2,  176,    3, 0x0a /* Public */,
      25,    2,  181,    3, 0x0a /* Public */,
      27,    2,  186,    3, 0x0a /* Public */,
      27,    1,  191,    3, 0x2a /* Public | MethodCloned */,
      29,    1,  194,    3, 0x0a /* Public */,
      30,    3,  197,    3, 0x0a /* Public */,
      30,    2,  204,    3, 0x2a /* Public | MethodCloned */,
      32,    1,  209,    3, 0x0a /* Public */,

 // slots: parameters
    0x80000000 | 2,
    0x80000000 | 2,
    QMetaType::QString, QMetaType::QString,    6,
    QMetaType::QString, QMetaType::QString, QMetaType::QString,    6,    7,
    QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString,    9,   10,   11,   12,
    QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString,    9,   10,   11,
    0x80000000 | 2, QMetaType::QString, QMetaType::QString,   10,   14,
    0x80000000 | 2, QMetaType::QString,   10,
    0x80000000 | 2, QMetaType::QString,   10,
    QMetaType::QObjectStar, 0x80000000 | 2, QMetaType::QString,   18,   19,
    0x80000000 | 2, QMetaType::QString,   21,
    0x80000000 | 2, 0x80000000 | 2, QMetaType::QString, QMetaType::QString,   18,   21,   22,
    0x80000000 | 2, 0x80000000 | 2, QMetaType::QString,   18,   21,
    0x80000000 | 2, 0x80000000 | 2, QMetaType::QString,   18,   24,
    0x80000000 | 2, 0x80000000 | 2, QMetaType::QString,   18,   26,
    0x80000000 | 2, 0x80000000 | 2, QMetaType::QString,   18,   28,
    0x80000000 | 2, 0x80000000 | 2,   18,
    0x80000000 | 2, 0x80000000 | 2,   18,
    QMetaType::QObjectStar, 0x80000000 | 2, QMetaType::QString, QMetaType::QUrl,   18,   22,   31,
    QMetaType::QObjectStar, 0x80000000 | 2, QMetaType::QString,   18,   22,
    0x80000000 | 33, QMetaType::QObjectStar,   18,

       0        // eod
};

void Kross::FormModule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FormModule *_t = static_cast<FormModule *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { QWidget* _r = _t->activeModalWidget();
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 1: { QWidget* _r = _t->activeWindow();
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->tr((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->tr((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->showMessageBox((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->showMessageBox((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QWidget* _r = _t->showProgressDialog((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 7: { QWidget* _r = _t->createDialog((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 8: { QWidget* _r = _t->createAssistant((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 9: { QObject* _r = _t->createLayout((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QObject**>(_a[0]) = std::move(_r); }  break;
        case 10: { QWidget* _r = _t->createWidget((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 11: { QWidget* _r = _t->createWidget((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 12: { QWidget* _r = _t->createWidget((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 13: { QWidget* _r = _t->createWidgetFromUI((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 14: { QWidget* _r = _t->createWidgetFromUIFile((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 15: { QWidget* _r = _t->createFileWidget((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 16: { QWidget* _r = _t->createFileWidget((*reinterpret_cast< QWidget*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 17: { QWidget* _r = _t->createListView((*reinterpret_cast< QWidget*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 18: { QObject* _r = _t->loadPart((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QUrl(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QObject**>(_a[0]) = std::move(_r); }  break;
        case 19: { QObject* _r = _t->loadPart((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QObject**>(_a[0]) = std::move(_r); }  break;
        case 20: { QAction* _r = _t->createAction((*reinterpret_cast< QObject*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QAction**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        }
    }
}

const QMetaObject Kross::FormModule::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Kross__FormModule.data,
      qt_meta_data_Kross__FormModule,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kross::FormModule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kross::FormModule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kross__FormModule.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kross::FormModule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
