/****************************************************************************
** Meta object code from reading C++ file 'action.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kross-5.39.0/src/core/action.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'action.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kross__Action_t {
    QByteArrayData data[42];
    char stringdata0[411];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kross__Action_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kross__Action_t qt_meta_stringdata_Kross__Action = {
    {
QT_MOC_LITERAL(0, 0, 13), // "Kross::Action"
QT_MOC_LITERAL(1, 14, 7), // "updated"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 11), // "dataChanged"
QT_MOC_LITERAL(4, 35, 7), // "Action*"
QT_MOC_LITERAL(5, 43, 7), // "started"
QT_MOC_LITERAL(6, 51, 14), // "Kross::Action*"
QT_MOC_LITERAL(7, 66, 8), // "finished"
QT_MOC_LITERAL(8, 75, 9), // "finalized"
QT_MOC_LITERAL(9, 85, 4), // "name"
QT_MOC_LITERAL(10, 90, 7), // "version"
QT_MOC_LITERAL(11, 98, 11), // "description"
QT_MOC_LITERAL(12, 110, 14), // "setDescription"
QT_MOC_LITERAL(13, 125, 8), // "iconName"
QT_MOC_LITERAL(14, 134, 11), // "setIconName"
QT_MOC_LITERAL(15, 146, 8), // "iconname"
QT_MOC_LITERAL(16, 155, 9), // "isEnabled"
QT_MOC_LITERAL(17, 165, 10), // "setEnabled"
QT_MOC_LITERAL(18, 176, 7), // "enabled"
QT_MOC_LITERAL(19, 184, 4), // "file"
QT_MOC_LITERAL(20, 189, 7), // "setFile"
QT_MOC_LITERAL(21, 197, 10), // "scriptfile"
QT_MOC_LITERAL(22, 208, 4), // "code"
QT_MOC_LITERAL(23, 213, 7), // "setCode"
QT_MOC_LITERAL(24, 221, 11), // "interpreter"
QT_MOC_LITERAL(25, 233, 14), // "setInterpreter"
QT_MOC_LITERAL(26, 248, 15), // "interpretername"
QT_MOC_LITERAL(27, 264, 11), // "currentPath"
QT_MOC_LITERAL(28, 276, 10), // "addQObject"
QT_MOC_LITERAL(29, 287, 3), // "obj"
QT_MOC_LITERAL(30, 291, 7), // "qobject"
QT_MOC_LITERAL(31, 299, 12), // "qobjectNames"
QT_MOC_LITERAL(32, 312, 7), // "options"
QT_MOC_LITERAL(33, 320, 6), // "option"
QT_MOC_LITERAL(34, 327, 12), // "defaultvalue"
QT_MOC_LITERAL(35, 340, 9), // "setOption"
QT_MOC_LITERAL(36, 350, 5), // "value"
QT_MOC_LITERAL(37, 356, 13), // "functionNames"
QT_MOC_LITERAL(38, 370, 12), // "callFunction"
QT_MOC_LITERAL(39, 383, 4), // "args"
QT_MOC_LITERAL(40, 388, 8), // "evaluate"
QT_MOC_LITERAL(41, 397, 13) // "slotTriggered"

    },
    "Kross::Action\0updated\0\0dataChanged\0"
    "Action*\0started\0Kross::Action*\0finished\0"
    "finalized\0name\0version\0description\0"
    "setDescription\0iconName\0setIconName\0"
    "iconname\0isEnabled\0setEnabled\0enabled\0"
    "file\0setFile\0scriptfile\0code\0setCode\0"
    "interpreter\0setInterpreter\0interpretername\0"
    "currentPath\0addQObject\0obj\0qobject\0"
    "qobjectNames\0options\0option\0defaultvalue\0"
    "setOption\0value\0functionNames\0"
    "callFunction\0args\0evaluate\0slotTriggered"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kross__Action[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      33,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  179,    2, 0x06 /* Public */,
       3,    1,  180,    2, 0x06 /* Public */,
       5,    1,  183,    2, 0x06 /* Public */,
       7,    1,  186,    2, 0x06 /* Public */,
       8,    1,  189,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    0,  192,    2, 0x0a /* Public */,
      10,    0,  193,    2, 0x0a /* Public */,
      11,    0,  194,    2, 0x0a /* Public */,
      12,    1,  195,    2, 0x0a /* Public */,
      13,    0,  198,    2, 0x0a /* Public */,
      14,    1,  199,    2, 0x0a /* Public */,
      16,    0,  202,    2, 0x0a /* Public */,
      17,    1,  203,    2, 0x0a /* Public */,
      19,    0,  206,    2, 0x0a /* Public */,
      20,    1,  207,    2, 0x0a /* Public */,
      22,    0,  210,    2, 0x0a /* Public */,
      23,    1,  211,    2, 0x0a /* Public */,
      24,    0,  214,    2, 0x0a /* Public */,
      25,    1,  215,    2, 0x0a /* Public */,
      27,    0,  218,    2, 0x0a /* Public */,
      28,    2,  219,    2, 0x0a /* Public */,
      28,    1,  224,    2, 0x2a /* Public | MethodCloned */,
      30,    1,  227,    2, 0x0a /* Public */,
      31,    0,  230,    2, 0x0a /* Public */,
      32,    0,  231,    2, 0x0a /* Public */,
      33,    2,  232,    2, 0x0a /* Public */,
      33,    1,  237,    2, 0x2a /* Public | MethodCloned */,
      35,    2,  240,    2, 0x0a /* Public */,
      37,    0,  245,    2, 0x0a /* Public */,
      38,    2,  246,    2, 0x0a /* Public */,
      38,    1,  251,    2, 0x2a /* Public | MethodCloned */,
      40,    1,  254,    2, 0x0a /* Public */,
      41,    0,  257,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 6,    2,

 // slots: parameters
    QMetaType::QString,
    QMetaType::Int,
    QMetaType::QString,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::QString,
    QMetaType::Void, QMetaType::QString,   15,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::QString,
    QMetaType::Bool, QMetaType::QString,   21,
    QMetaType::QByteArray,
    QMetaType::Void, QMetaType::QByteArray,   22,
    QMetaType::QString,
    QMetaType::Void, QMetaType::QString,   26,
    QMetaType::QString,
    QMetaType::Void, QMetaType::QObjectStar, QMetaType::QString,   29,    9,
    QMetaType::Void, QMetaType::QObjectStar,   29,
    QMetaType::QObjectStar, QMetaType::QString,    9,
    QMetaType::QStringList,
    QMetaType::QVariantMap,
    QMetaType::QVariant, QMetaType::QString, QMetaType::QVariant,    9,   34,
    QMetaType::QVariant, QMetaType::QString,    9,
    QMetaType::Bool, QMetaType::QString, QMetaType::QVariant,    9,   36,
    QMetaType::QStringList,
    QMetaType::QVariant, QMetaType::QString, QMetaType::QVariantList,    9,   39,
    QMetaType::QVariant, QMetaType::QString,    9,
    QMetaType::QVariant, QMetaType::QByteArray,   22,
    QMetaType::Void,

       0        // eod
};

void Kross::Action::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Action *_t = static_cast<Action *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updated(); break;
        case 1: _t->dataChanged((*reinterpret_cast< Action*(*)>(_a[1]))); break;
        case 2: _t->started((*reinterpret_cast< Kross::Action*(*)>(_a[1]))); break;
        case 3: _t->finished((*reinterpret_cast< Kross::Action*(*)>(_a[1]))); break;
        case 4: _t->finalized((*reinterpret_cast< Kross::Action*(*)>(_a[1]))); break;
        case 5: { QString _r = _t->name();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { int _r = _t->version();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->description();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->setDescription((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: { QString _r = _t->iconName();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setIconName((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: { bool _r = _t->isEnabled();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->setEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: { QString _r = _t->file();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->setFile((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { QByteArray _r = _t->code();
            if (_a[0]) *reinterpret_cast< QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->setCode((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 17: { QString _r = _t->interpreter();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->setInterpreter((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 19: { QString _r = _t->currentPath();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->addQObject((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 21: _t->addQObject((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 22: { QObject* _r = _t->qobject((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QObject**>(_a[0]) = std::move(_r); }  break;
        case 23: { QStringList _r = _t->qobjectNames();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 24: { QVariantMap _r = _t->options();
            if (_a[0]) *reinterpret_cast< QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 25: { QVariant _r = _t->option((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QVariant*>(_a[0]) = std::move(_r); }  break;
        case 26: { QVariant _r = _t->option((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariant*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->setOption((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { QStringList _r = _t->functionNames();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 29: { QVariant _r = _t->callFunction((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantList(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QVariant*>(_a[0]) = std::move(_r); }  break;
        case 30: { QVariant _r = _t->callFunction((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariant*>(_a[0]) = std::move(_r); }  break;
        case 31: { QVariant _r = _t->evaluate((*reinterpret_cast< const QByteArray(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariant*>(_a[0]) = std::move(_r); }  break;
        case 32: _t->slotTriggered(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Action* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Kross::Action* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Kross::Action* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Kross::Action* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (Action::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Action::updated)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Action::*_t)(Action * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Action::dataChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Action::*_t)(Kross::Action * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Action::started)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Action::*_t)(Kross::Action * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Action::finished)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Action::*_t)(Kross::Action * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Action::finalized)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject Kross::Action::staticMetaObject = {
    { &QAction::staticMetaObject, qt_meta_stringdata_Kross__Action.data,
      qt_meta_data_Kross__Action,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kross::Action::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kross::Action::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kross__Action.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QScriptable"))
        return static_cast< QScriptable*>(this);
    if (!strcmp(_clname, "ChildrenInterface"))
        return static_cast< ChildrenInterface*>(this);
    if (!strcmp(_clname, "ErrorInterface"))
        return static_cast< ErrorInterface*>(this);
    return QAction::qt_metacast(_clname);
}

int Kross::Action::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAction::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    return _id;
}

// SIGNAL 0
void Kross::Action::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Kross::Action::dataChanged(Action * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Kross::Action::started(Kross::Action * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Kross::Action::finished(Kross::Action * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Kross::Action::finalized(Kross::Action * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
