/****************************************************************************
** Meta object code from reading C++ file 'translation.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kross-5.39.0/src/modules/translation.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'translation.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kross__TranslationModule_t {
    QByteArrayData data[12];
    char stringdata0[96];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kross__TranslationModule_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kross__TranslationModule_t qt_meta_stringdata_Kross__TranslationModule = {
    {
QT_MOC_LITERAL(0, 0, 24), // "Kross::TranslationModule"
QT_MOC_LITERAL(1, 25, 4), // "i18n"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 4), // "text"
QT_MOC_LITERAL(4, 36, 9), // "arguments"
QT_MOC_LITERAL(5, 46, 5), // "i18nc"
QT_MOC_LITERAL(6, 52, 7), // "context"
QT_MOC_LITERAL(7, 60, 5), // "i18np"
QT_MOC_LITERAL(8, 66, 8), // "singular"
QT_MOC_LITERAL(9, 75, 6), // "plural"
QT_MOC_LITERAL(10, 82, 6), // "number"
QT_MOC_LITERAL(11, 89, 6) // "i18ncp"

    },
    "Kross::TranslationModule\0i18n\0\0text\0"
    "arguments\0i18nc\0context\0i18np\0singular\0"
    "plural\0number\0i18ncp"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kross__TranslationModule[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   54,    2, 0x0a /* Public */,
       1,    1,   59,    2, 0x2a /* Public | MethodCloned */,
       5,    3,   62,    2, 0x0a /* Public */,
       5,    2,   69,    2, 0x2a /* Public | MethodCloned */,
       7,    4,   74,    2, 0x0a /* Public */,
       7,    3,   83,    2, 0x2a /* Public | MethodCloned */,
      11,    5,   90,    2, 0x0a /* Public */,
      11,    4,  101,    2, 0x2a /* Public | MethodCloned */,

 // slots: parameters
    QMetaType::QString, QMetaType::QString, QMetaType::QVariantList,    3,    4,
    QMetaType::QString, QMetaType::QString,    3,
    QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QVariantList,    6,    3,    4,
    QMetaType::QString, QMetaType::QString, QMetaType::QString,    6,    3,
    QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Int, QMetaType::QVariantList,    8,    9,   10,    4,
    QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Int,    8,    9,   10,
    QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Int, QMetaType::QVariantList,    6,    8,    9,   10,    4,
    QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Int,    6,    8,    9,   10,

       0        // eod
};

void Kross::TranslationModule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TranslationModule *_t = static_cast<TranslationModule *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { QString _r = _t->i18n((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantList(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->i18n((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->i18nc((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QVariantList(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->i18nc((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->i18np((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QVariantList(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->i18np((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->i18ncp((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< const QVariantList(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->i18ncp((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject Kross::TranslationModule::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Kross__TranslationModule.data,
      qt_meta_data_Kross__TranslationModule,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kross::TranslationModule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kross::TranslationModule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kross__TranslationModule.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kross::TranslationModule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
