/****************************************************************************
** Meta object code from reading C++ file 'actioncollection.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kross-5.39.0/src/core/actioncollection.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'actioncollection.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kross__ActionCollection_t {
    QByteArrayData data[17];
    char stringdata0[244];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kross__ActionCollection_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kross__ActionCollection_t qt_meta_stringdata_Kross__ActionCollection = {
    {
QT_MOC_LITERAL(0, 0, 23), // "Kross::ActionCollection"
QT_MOC_LITERAL(1, 24, 7), // "updated"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 11), // "dataChanged"
QT_MOC_LITERAL(4, 45, 7), // "Action*"
QT_MOC_LITERAL(5, 53, 17), // "ActionCollection*"
QT_MOC_LITERAL(6, 71, 22), // "collectionToBeInserted"
QT_MOC_LITERAL(7, 94, 5), // "child"
QT_MOC_LITERAL(8, 100, 6), // "parent"
QT_MOC_LITERAL(9, 107, 18), // "collectionInserted"
QT_MOC_LITERAL(10, 126, 21), // "collectionToBeRemoved"
QT_MOC_LITERAL(11, 148, 17), // "collectionRemoved"
QT_MOC_LITERAL(12, 166, 18), // "actionToBeInserted"
QT_MOC_LITERAL(13, 185, 14), // "actionInserted"
QT_MOC_LITERAL(14, 200, 17), // "actionToBeRemoved"
QT_MOC_LITERAL(15, 218, 13), // "actionRemoved"
QT_MOC_LITERAL(16, 232, 11) // "emitUpdated"

    },
    "Kross::ActionCollection\0updated\0\0"
    "dataChanged\0Action*\0ActionCollection*\0"
    "collectionToBeInserted\0child\0parent\0"
    "collectionInserted\0collectionToBeRemoved\0"
    "collectionRemoved\0actionToBeInserted\0"
    "actionInserted\0actionToBeRemoved\0"
    "actionRemoved\0emitUpdated"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kross__ActionCollection[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      11,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x06 /* Public */,
       3,    1,   75,    2, 0x06 /* Public */,
       3,    1,   78,    2, 0x06 /* Public */,
       6,    2,   81,    2, 0x06 /* Public */,
       9,    2,   86,    2, 0x06 /* Public */,
      10,    2,   91,    2, 0x06 /* Public */,
      11,    2,   96,    2, 0x06 /* Public */,
      12,    2,  101,    2, 0x06 /* Public */,
      13,    2,  106,    2, 0x06 /* Public */,
      14,    2,  111,    2, 0x06 /* Public */,
      15,    2,  116,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      16,    0,  121,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 5,    7,    8,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 5,    7,    8,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 5,    7,    8,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 5,    7,    8,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 5,    7,    8,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 5,    7,    8,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 5,    7,    8,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 5,    7,    8,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void Kross::ActionCollection::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ActionCollection *_t = static_cast<ActionCollection *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updated(); break;
        case 1: _t->dataChanged((*reinterpret_cast< Action*(*)>(_a[1]))); break;
        case 2: _t->dataChanged((*reinterpret_cast< ActionCollection*(*)>(_a[1]))); break;
        case 3: _t->collectionToBeInserted((*reinterpret_cast< ActionCollection*(*)>(_a[1])),(*reinterpret_cast< ActionCollection*(*)>(_a[2]))); break;
        case 4: _t->collectionInserted((*reinterpret_cast< ActionCollection*(*)>(_a[1])),(*reinterpret_cast< ActionCollection*(*)>(_a[2]))); break;
        case 5: _t->collectionToBeRemoved((*reinterpret_cast< ActionCollection*(*)>(_a[1])),(*reinterpret_cast< ActionCollection*(*)>(_a[2]))); break;
        case 6: _t->collectionRemoved((*reinterpret_cast< ActionCollection*(*)>(_a[1])),(*reinterpret_cast< ActionCollection*(*)>(_a[2]))); break;
        case 7: _t->actionToBeInserted((*reinterpret_cast< Action*(*)>(_a[1])),(*reinterpret_cast< ActionCollection*(*)>(_a[2]))); break;
        case 8: _t->actionInserted((*reinterpret_cast< Action*(*)>(_a[1])),(*reinterpret_cast< ActionCollection*(*)>(_a[2]))); break;
        case 9: _t->actionToBeRemoved((*reinterpret_cast< Action*(*)>(_a[1])),(*reinterpret_cast< ActionCollection*(*)>(_a[2]))); break;
        case 10: _t->actionRemoved((*reinterpret_cast< Action*(*)>(_a[1])),(*reinterpret_cast< ActionCollection*(*)>(_a[2]))); break;
        case 11: _t->emitUpdated(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Action* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ActionCollection* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ActionCollection* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ActionCollection* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ActionCollection* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ActionCollection* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Action* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ActionCollection* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Action* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ActionCollection* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Action* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ActionCollection* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Action* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ActionCollection* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ActionCollection::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ActionCollection::updated)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ActionCollection::*_t)(Action * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ActionCollection::dataChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ActionCollection::*_t)(ActionCollection * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ActionCollection::dataChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (ActionCollection::*_t)(ActionCollection * , ActionCollection * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ActionCollection::collectionToBeInserted)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (ActionCollection::*_t)(ActionCollection * , ActionCollection * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ActionCollection::collectionInserted)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (ActionCollection::*_t)(ActionCollection * , ActionCollection * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ActionCollection::collectionToBeRemoved)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (ActionCollection::*_t)(ActionCollection * , ActionCollection * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ActionCollection::collectionRemoved)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (ActionCollection::*_t)(Action * , ActionCollection * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ActionCollection::actionToBeInserted)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (ActionCollection::*_t)(Action * , ActionCollection * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ActionCollection::actionInserted)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (ActionCollection::*_t)(Action * , ActionCollection * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ActionCollection::actionToBeRemoved)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (ActionCollection::*_t)(Action * , ActionCollection * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ActionCollection::actionRemoved)) {
                *result = 10;
                return;
            }
        }
    }
}

const QMetaObject Kross::ActionCollection::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Kross__ActionCollection.data,
      qt_meta_data_Kross__ActionCollection,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kross::ActionCollection::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kross::ActionCollection::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kross__ActionCollection.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kross::ActionCollection::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Kross::ActionCollection::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Kross::ActionCollection::dataChanged(Action * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Kross::ActionCollection::dataChanged(ActionCollection * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Kross::ActionCollection::collectionToBeInserted(ActionCollection * _t1, ActionCollection * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Kross::ActionCollection::collectionInserted(ActionCollection * _t1, ActionCollection * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Kross::ActionCollection::collectionToBeRemoved(ActionCollection * _t1, ActionCollection * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Kross::ActionCollection::collectionRemoved(ActionCollection * _t1, ActionCollection * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Kross::ActionCollection::actionToBeInserted(Action * _t1, ActionCollection * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Kross::ActionCollection::actionInserted(Action * _t1, ActionCollection * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void Kross::ActionCollection::actionToBeRemoved(Action * _t1, ActionCollection * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void Kross::ActionCollection::actionRemoved(Action * _t1, ActionCollection * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
