/****************************************************************************
** Meta object code from reading C++ file 'manager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kross-5.39.0/src/core/manager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'manager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kross__Manager_t {
    QByteArrayData data[18];
    char stringdata0[174];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kross__Manager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kross__Manager_t qt_meta_stringdata_Kross__Manager = {
    {
QT_MOC_LITERAL(0, 0, 14), // "Kross::Manager"
QT_MOC_LITERAL(1, 15, 7), // "started"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 14), // "Kross::Action*"
QT_MOC_LITERAL(4, 39, 8), // "finished"
QT_MOC_LITERAL(5, 48, 12), // "interpreters"
QT_MOC_LITERAL(6, 61, 9), // "hasAction"
QT_MOC_LITERAL(7, 71, 4), // "name"
QT_MOC_LITERAL(8, 76, 6), // "action"
QT_MOC_LITERAL(9, 83, 6), // "module"
QT_MOC_LITERAL(10, 90, 10), // "modulename"
QT_MOC_LITERAL(11, 101, 13), // "deleteModules"
QT_MOC_LITERAL(12, 115, 17), // "executeScriptFile"
QT_MOC_LITERAL(13, 133, 4), // "file"
QT_MOC_LITERAL(14, 138, 10), // "addQObject"
QT_MOC_LITERAL(15, 149, 3), // "obj"
QT_MOC_LITERAL(16, 153, 7), // "qobject"
QT_MOC_LITERAL(17, 161, 12) // "qobjectNames"

    },
    "Kross::Manager\0started\0\0Kross::Action*\0"
    "finished\0interpreters\0hasAction\0name\0"
    "action\0module\0modulename\0deleteModules\0"
    "executeScriptFile\0file\0addQObject\0obj\0"
    "qobject\0qobjectNames"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kross__Manager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   79,    2, 0x06 /* Public */,
       4,    1,   82,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    0,   85,    2, 0x0a /* Public */,
       6,    1,   86,    2, 0x0a /* Public */,
       8,    1,   89,    2, 0x0a /* Public */,
       9,    1,   92,    2, 0x0a /* Public */,
      11,    0,   95,    2, 0x0a /* Public */,
      12,    1,   96,    2, 0x0a /* Public */,
      12,    0,   99,    2, 0x2a /* Public | MethodCloned */,
      14,    2,  100,    2, 0x0a /* Public */,
      14,    1,  105,    2, 0x2a /* Public | MethodCloned */,
      16,    1,  108,    2, 0x0a /* Public */,
      17,    0,  111,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 3,    2,

 // slots: parameters
    QMetaType::QStringList,
    QMetaType::Bool, QMetaType::QString,    7,
    QMetaType::QObjectStar, QMetaType::QString,    7,
    QMetaType::QObjectStar, QMetaType::QString,   10,
    QMetaType::Void,
    QMetaType::Bool, QMetaType::QUrl,   13,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::QObjectStar, QMetaType::QString,   15,    7,
    QMetaType::Void, QMetaType::QObjectStar,   15,
    QMetaType::QObjectStar, QMetaType::QString,    7,
    QMetaType::QStringList,

       0        // eod
};

void Kross::Manager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Manager *_t = static_cast<Manager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->started((*reinterpret_cast< Kross::Action*(*)>(_a[1]))); break;
        case 1: _t->finished((*reinterpret_cast< Kross::Action*(*)>(_a[1]))); break;
        case 2: { QStringList _r = _t->interpreters();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->hasAction((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { QObject* _r = _t->action((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QObject**>(_a[0]) = std::move(_r); }  break;
        case 5: { QObject* _r = _t->module((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QObject**>(_a[0]) = std::move(_r); }  break;
        case 6: _t->deleteModules(); break;
        case 7: { bool _r = _t->executeScriptFile((*reinterpret_cast< const QUrl(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->executeScriptFile();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->addQObject((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 10: _t->addQObject((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 11: { QObject* _r = _t->qobject((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QObject**>(_a[0]) = std::move(_r); }  break;
        case 12: { QStringList _r = _t->qobjectNames();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (Manager::*_t)(Kross::Action * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Manager::started)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Manager::*_t)(Kross::Action * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Manager::finished)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject Kross::Manager::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Kross__Manager.data,
      qt_meta_data_Kross__Manager,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kross::Manager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kross::Manager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kross__Manager.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QScriptable"))
        return static_cast< QScriptable*>(this);
    if (!strcmp(_clname, "ChildrenInterface"))
        return static_cast< ChildrenInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int Kross::Manager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Kross::Manager::started(Kross::Action * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Kross::Manager::finished(Kross::Action * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
